@@ -342,7 +342,7 @@ static void on_popup_location_changed(GSettings *settings, gchar *key, NotifyDae
 	{
 		int j;
 
-		for (j = 0; j < daemon->priv->n_screens; j++)
+		for (j = 0; j < daemon->priv->screens[i]->n_stacks; j++)
 		{
 			NotifyStack* stack;
 			stack = daemon->priv->screens[i]->stacks[j];
@@ -364,12 +364,12 @@ static void notify_daemon_init(NotifyDaemon* daemon)
 
 	daemon->gsettings = g_settings_new (GSETTINGS_SCHEMA);
 
+	g_signal_connect (daemon->gsettings, "changed::" GSETTINGS_KEY_POPUP_LOCATION, G_CALLBACK (on_popup_location_changed), daemon);
+
 	location = g_settings_get_string (daemon->gsettings, GSETTINGS_KEY_POPUP_LOCATION);
 	daemon->priv->stack_location = get_stack_location_from_string(location);
 	g_free(location);
 
-	g_signal_connect (daemon->gsettings, "changed::" GSETTINGS_KEY_POPUP_LOCATION, G_CALLBACK (on_popup_location_changed), daemon);
-
 	daemon->priv->n_screens = 0;
 	daemon->priv->screens = NULL;
 
@@ -399,7 +399,7 @@ static void destroy_screens(NotifyDaemon* daemon)
 		gdkwindow = gdk_screen_get_root_window(screen);
 		gdk_window_remove_filter(gdkwindow, (GdkFilterFunc) screen_xevent_filter, daemon->priv->screens[i]);
 
-		for (j = 0; i < daemon->priv->screens[i]->n_stacks; j++)
+		for (j = 0; j < daemon->priv->screens[i]->n_stacks; j++)
 		{
 			notify_stack_destroy(daemon->priv->screens[i]->stacks[j]);
 			daemon->priv->screens[i]->stacks[j] = NULL;
@@ -1162,6 +1162,11 @@ static gboolean fullscreen_window_exists(GtkWidget* nw)
 
 	wnck_workspace = wnck_screen_get_active_workspace (wnck_screen);
 
+	if (!wnck_workspace)
+	{
+		return FALSE;
+	}
+
 	for (l = wnck_screen_get_windows_stacked (wnck_screen); l != NULL; l = l->next)
 	{
 		WnckWindow *wnck_win = (WnckWindow *) l->data;
